summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/tab_contents.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-13 19:41:40 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-13 19:41:40 +0000
commitd0980792d29b16ef195255639f8c8aca8c969e93 (patch)
tree8c6a20bb41ecd094556af7a26d1535dc7dd4bc88 /chrome/browser/tab_contents/tab_contents.cc
parenta08ebeaea39acfe007d9ee9b25b28efd04011e5a (diff)
downloadchromium_src-d0980792d29b16ef195255639f8c8aca8c969e93.zip
chromium_src-d0980792d29b16ef195255639f8c8aca8c969e93.tar.gz
chromium_src-d0980792d29b16ef195255639f8c8aca8c969e93.tar.bz2
WebUI: Get rid of more references to DOMUI in the rest of the directories.
BUG=59945 TEST=trybots Review URL: http://codereview.chromium.org/6513010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@74771 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents/tab_contents.cc')
-rw-r--r--chrome/browser/tab_contents/tab_contents.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/tab_contents/tab_contents.cc b/chrome/browser/tab_contents/tab_contents.cc
index 46f87e1..cbfe33f 100644
--- a/chrome/browser/tab_contents/tab_contents.cc
+++ b/chrome/browser/tab_contents/tab_contents.cc
@@ -667,7 +667,7 @@ bool TabContents::ShouldDisplayURL() {
return true;
}
- WebUI* web_ui = GetDOMUIForCurrentState();
+ WebUI* web_ui = GetWebUIForCurrentState();
if (web_ui)
return !web_ui->should_hide_url();
return true;
@@ -703,7 +703,7 @@ bool TabContents::ShouldDisplayFavIcon() {
if (controller_.GetLastCommittedEntry() && controller_.pending_entry())
return true;
- WebUI* web_ui = GetDOMUIForCurrentState();
+ WebUI* web_ui = GetWebUIForCurrentState();
if (web_ui)
return !web_ui->hide_favicon();
return true;
@@ -1093,7 +1093,7 @@ void TabContents::FocusThroughTabTraversal(bool reverse) {
}
bool TabContents::FocusLocationBarByDefault() {
- WebUI* web_ui = GetDOMUIForCurrentState();
+ WebUI* web_ui = GetWebUIForCurrentState();
if (web_ui)
return web_ui->focus_location_bar_by_default();
NavigationEntry* entry = controller_.GetActiveEntry();
@@ -1198,7 +1198,7 @@ bool TabContents::ShouldShowBookmarkBar() {
if (!browser_defaults::bookmarks_enabled)
return false;
// See GetDOMUIForCurrentState() comment for more info. This case is very
// similar, but for non-first loads, we want to use the committed entry. This
// is so the bookmarks bar disappears at the same time the page does.
if (controller_.GetLastCommittedEntry()) {
@@ -1208,7 +1208,7 @@ bool TabContents::ShouldShowBookmarkBar() {
}
// When it's the first load, we know either the pending one or the committed
// one will have the Web UI in it (see GetDOMUIForCurrentState), and only one
// of them will be valid, so we can just check both.
if (render_manager_.pending_web_ui())
return render_manager_.pending_web_ui()->force_bookmark_bar_visible();
@@ -1733,7 +1733,7 @@ void TabContents::ExpireInfoBars(
}
}
-WebUI* TabContents::GetDOMUIForCurrentState() {
+WebUI* TabContents::GetWebUIForCurrentState() {
// When there is a pending navigation entry, we want to use the pending WebUI
// that goes along with it to control the basic flags. For example, we want to
// show the pending URL in the URL bar, so we want the display_url flag to
@@ -1785,7 +1785,7 @@ void TabContents::DidNavigateMainFramePostCommit(
WebUI* web_ui = WebUIFactory::CreateWebUIForURL(this, GetURL());
// web_ui might be NULL if the URL refers to a non-existent extension.
if (web_ui) {
- render_manager_.SetDOMUIPostCommit(web_ui);
+ render_manager_.SetWebUIPostCommit(web_ui);
web_ui->RenderViewCreated(render_view_host());
}
}
@@ -2949,7 +2949,7 @@ NavigationController& TabContents::GetControllerForRenderManager() {
return controller();
}
-WebUI* TabContents::CreateDOMUIForRenderManager(const GURL& url) {
+WebUI* TabContents::CreateWebUIForRenderManager(const GURL& url) {
return WebUIFactory::CreateWebUIForURL(this, url);
}
@@ -1198,7 +1198,7 @@ bool TabContents::ShouldShowBookmarkBar() {
if (!browser_defaults::bookmarks_enabled)
return false;
- // See GetDOMUIForCurrentState() comment for more info. This case is very
+ // See GetWebUIForCurrentState() comment for more info. This case is very
// similar, but for non-first loads, we want to use the committed entry. This
// is so the bookmarks bar disappears at the same time the page does.
@@ -1208,7 +1208,7 @@ bool TabContents::ShouldShowBookmarkBar() {
}
// When it's the first load, we know either the pending one or the committed
- // one will have the Web UI in it (see GetDOMUIForCurrentState), and only one
+ // one will have the Web UI in it (see GetWebUIForCurrentState), and only one
// of them will be valid, so we can just check both.
if (render_manager_.pending_web_ui())